#[repr(u32)]pub enum StrangePart {
Show 52 variants
ScoutsKilled = 10,
SnipersKilled = 11,
SoldiersKilled = 12,
DemomenKilled = 13,
HeaviesKilled = 14,
PyrosKilled = 15,
SpiesKilled = 16,
EngineersKilled = 17,
MedicsKilled = 18,
BuildingsDestroyed = 19,
ProjectilesReflected = 20,
HeadshotKills = 21,
AirborneEnemyKills = 22,
GibKills = 23,
KillsUnderAFullMoon = 27,
Dominations = 28,
Revenges = 30,
PosthumousKills = 31,
TeammatesExtinguished = 32,
CriticalKills = 33,
KillsWhileExplosiveJumping = 34,
SappersRemoved = 36,
CloakedSpiesKilled = 37,
MedicsKilledThatHaveFullUberCharge = 38,
RobotsDestroyed = 39,
GiantRobotsDestroyed = 40,
KillsWhileLowHealth = 44,
KillsDuringHalloween = 45,
RobotsKilledDuringHalloween = 46,
DefenderKills = 47,
SubmergedEnemyKills = 48,
KillsWhileInvulnUberCharged = 49,
TanksDestroyed = 61,
LongDistanceKills = 62,
KillsDuringVictoryTime = 67,
RobotScoutsDestroyed = 68,
RobotSpiesDestroyed = 74,
TauntKills = 77,
UnusualWearingPlayerKills = 78,
BurningPlayerKills = 79,
KillstreaksEnded = 80,
FreezecamTauntAppearances = 81,
DamageDealt = 82,
FiresSurvived = 83,
AlliedHealingDone = 84,
PointBlankKills = 85,
Kills = 87,
FullHealthKills = 88,
TauntingPlayerKills = 89,
NotCritNorMiniCritKills = 93,
PlayerHits = 94,
Assists = 95,
}Expand description
Strange part. repr values are mapped to their kill_eater_score_type attribute value. Strings
are the name of the kill_eater_score_type, not the name of the strange part.
Variants
ScoutsKilled = 10
SnipersKilled = 11
SoldiersKilled = 12
DemomenKilled = 13
HeaviesKilled = 14
PyrosKilled = 15
SpiesKilled = 16
EngineersKilled = 17
MedicsKilled = 18
BuildingsDestroyed = 19
ProjectilesReflected = 20
HeadshotKills = 21
AirborneEnemyKills = 22
GibKills = 23
KillsUnderAFullMoon = 27
Dominations = 28
Revenges = 30
PosthumousKills = 31
TeammatesExtinguished = 32
CriticalKills = 33
KillsWhileExplosiveJumping = 34
SappersRemoved = 36
CloakedSpiesKilled = 37
MedicsKilledThatHaveFullUberCharge = 38
RobotsDestroyed = 39
GiantRobotsDestroyed = 40
KillsWhileLowHealth = 44
KillsDuringHalloween = 45
RobotsKilledDuringHalloween = 46
DefenderKills = 47
SubmergedEnemyKills = 48
KillsWhileInvulnUberCharged = 49
TanksDestroyed = 61
LongDistanceKills = 62
KillsDuringVictoryTime = 67
RobotScoutsDestroyed = 68
RobotSpiesDestroyed = 74
TauntKills = 77
UnusualWearingPlayerKills = 78
BurningPlayerKills = 79
KillstreaksEnded = 80
FreezecamTauntAppearances = 81
DamageDealt = 82
FiresSurvived = 83
AlliedHealingDone = 84
PointBlankKills = 85
Kills = 87
FullHealthKills = 88
TauntingPlayerKills = 89
NotCritNorMiniCritKills = 93
PlayerHits = 94
Assists = 95
Implementations
Sourceimpl StrangePart
impl StrangePart
Sourcepub fn score_type(&self) -> u32
pub fn score_type(&self) -> u32
Gets the kill_eater_score_type attribute value for this StrangePart.
Sourcepub fn from_score_type(score_type: u32) -> Option<Self>
pub fn from_score_type(score_type: u32) -> Option<Self>
Converts a kill_eater_score_type attribute value into a StrangePart.
Sourcepub fn strange_part_name(&self) -> &'static str
pub fn strange_part_name(&self) -> &'static str
Gets the name of the strange part for this StrangePart.
Sourcepub fn from_strange_part_name(name: &str) -> Option<StrangePart>
pub fn from_strange_part_name(name: &str) -> Option<StrangePart>
Gets the related StrangePart by its strange part name, if it exists.
Sourcepub fn is_cosmetic_part(&self) -> bool
pub fn is_cosmetic_part(&self) -> bool
Is this strange part for cosmetics?
Sourcepub fn kill_eater_score_type(&self) -> Option<KillEaterScoreType>
pub fn kill_eater_score_type(&self) -> Option<KillEaterScoreType>
Converts this StrangePart into its related KillEaterScoreType, if it exists.